tags = [
    ("a", True),
    ("abbr", True),
    ("address", True),
    ("area", False),
    ("article", True),
    ("aside", True),
    ("audio", True),
    ("base", False),
    ("blockquote", True),
    ("body", True),
    ("br", False),
    ("button", True),
    ("canvas", True),
    ("caption", True),
    ("circle", True),
    ("cite", True),
    ("code", True),
    ("col", False),
    ("colgroup", True),
    ("data", True),
    ("datalist", True),
    ("dd", True),
    ("del_", True),
    ("details", True),
    ("dialog", True),
    ("div", True),
    ("dl", True),
    ("dt", True),
    ("ellipse", True),
    ("em", True),
    ("embed", False),
    ("fieldset", True),
    ("figcaption", True),
    ("figure", True),
    ("footer", True),
    ("form", True),
    ("h1", True),
    ("h2", True),
    ("h3", True),
    ("h4", True),
    ("h5", True),
    ("h6", True),
    ("head", True),
    ("header", True),
    ("hr", False),
    ("html", True),
    ("iframe", True),
    ("img", False),
    ("input", False),
    ("kbd", True),
    ("label", True),
    ("legend", True),
    ("li", True),
    ("link", False),
    ("main", True),
    ("map", True),
    ("mark", True),
    ("menu", True),
    ("meta", False),
    ("meter", True),
    ("nav", True),
    ("noscript", True),
    ("ol", True),
    ("optgroup", True),
    ("option", True),
    ("output", True),
    ("p", True),
    ("picture", True),
    ("polygon", True),
    ("portal", True),
    ("pre", True),
    ("progress", True),
    ("param", False),
    ("q", True),
    ("rect", True),
    ("s", True),
    ("samp", True),
    ("script", True),
    ("section", True),
    ("select", True),
    ("slot", True),
    ("small", True),
    ("source", False),
    ("span", True),
    ("strong", True),
    ("style", True),
    ("sub", True),
    ("summary", True),
    ("sup", True),
    ("svg", True),
    ("table", True),
    ("tbody", True),
    ("td", True),
    ("template", True),
    ("text", True),
    ("textarea", True),
    ("tfoot", True),
    ("th", True),
    ("thead", True),
    ("time", True),
    ("title", True),
    ("tr", True),
    ("track", False),
    ("u", True),
    ("ul", True),
    ("var", True),
    ("video", True),
    ("wbr", False),
]
