from .main import (
    a,
    abbr,
    address,
    area,
    article,
    aside,
    audio,
    base,
    blockquote,
    body,
    br,
    button,
    canvas,
    caption,
    circle,
    cite,
    code,
    col,
    colgroup,
    data,
    datalist,
    dd,
    del_,
    details,
    dialog,
    div,
    dl,
    dt,
    ellipse,
    em,
    embed,
    fieldset,
    figcaption,
    figure,
    footer,
    form,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    head,
    header,
    hr,
    html,
    iframe,
    img,
    input,
    kbd,
    label,
    legend,
    li,
    link,
    main,
    map,
    mark,
    menu,
    meta,
    meter,
    nav,
    noscript,
    ol,
    optgroup,
    option,
    output,
    p,
    picture,
    polygon,
    portal,
    pre,
    progress,
    param,
    q,
    rect,
    s,
    samp,
    script,
    section,
    select,
    slot,
    small,
    source,
    span,
    strong,
    style,
    sub,
    summary,
    sup,
    svg,
    table,
    tbody,
    td,
    template,
    text,
    textarea,
    tfoot,
    th,
    thead,
    time,
    title,
    tr,
    track,
    u,
    ul,
    var,
    video,
    wbr,
)
